thriftworker
============

CI status: [![Build Status](https://secure.travis-ci.org/blackwithwhite666/thriftworker.png?branch=master)](http://travis-ci.org/blackwithwhite666/thriftworker)

Listen given socket, parse and process given message and return result when needed.
